nested_lists_columns.pdf

## Metadata

Title | nested_lists_columns.pdf
Path | C:\Users\jenni\OneDrive\Documents\Code\burdoc\burdoc\tests\integration\data\inputs\nested_lists_columns.pdf
Pages | 0,1
PDF Metadata: format | PDF 1.7
PDF Metadata: title |
PDF Metadata: author | Joe Ennis
PDF Metadata: subject |
PDF Metadata: keywords |
PDF Metadata: creator | Microsoft® Word for Microsoft 365
PDF Metadata: producer | Microsoft® Word for Microsoft 365
PDF Metadata: creationDate | D:20230403060045+01'00'
PDF Metadata: modDate | D:20230403060045+01'00'
PDF Metadata: trapped |
PDF Metadata: encryption |

## Contents

1. Page 0
2. Page 1

#### Page 0

No images

#### Page 1

No images

Path: | content.0.[0,0].bbox
Type: | addition

Key | Old | New
x1 |  | 282.7159729003906
y1 |  | 154.79135131835938
y0 |  | 73.70773315429688
x0 |  | 90.02400207519531

Path: | content.0.[1,1].bbox
Type: | addition

Key | Old | New
x1 |  | 282.6080017089844
y1 |  | 389.3377380371094
y0 |  | 156.50772094726562
x0 |  | 126.0199966430664

Path: | content.0.[2,2].bbox
Type: | addition

Key | Old | New
x1 |  | 275.989990234375
y1 |  | 472.15771484375
y0 |  | 391.15771484375
x0 |  | 90.02400207519531

Path: | content.0.[3,3].bbox
Type: | addition

Key | Old | New
x1 |  | 283.9700012207031
y1 |  | 638.2313232421875
y0 |  | 515.7176513671875
x0 |  | 72.02400207519531

Path: | content.0.[4,4].bbox
Type: | addition

Key | Old | New
x1 |  | 282.7159729003906
y1 |  | 665.831298828125
y0 |  | 653.7476806640625
x0 |  | 90.02400207519531

Path: | content.0.[5,5].bbox
Type: | addition

Key | Old | New
x1 |  | 274.1960144042969
y1 |  | 693.34765625
y0 |  | 681.34765625
x0 |  | 108.0199966430664

Path: | content.0.[6,6].bbox
Type: | addition

Key | Old | New
x1 |  | 153.3800048828125
y1 |  | 720.9476928710938
y0 |  | 708.9476928710938
x0 |  | 108.0199966430664

Path: | content.0.[7,7].bbox
Type: | addition

Key | Old | New
x1 |  | 516.39404296875
y1 |  | 168.59133911132812
y0 |  | 73.70773315429688
x0 |  | 333.42999267578125

Path: | content.0.[8,8].bbox
Type: | addition

Key | Old | New
x1 |  | 519.3700561523438
y1 |  | 196.10769653320312
y0 |  | 184.10769653320312
x0 |  | 351.42999267578125

Path: | content.0.[9,9].bbox
Type: | addition

Key | Old | New
x1 |  | 425.3500061035156
y1 |  | 223.70773315429688
y0 |  | 211.70773315429688
x0 |  | 351.42999267578125

Path: | content.0.[10,10].bbox
Type: | addition

Key | Old | New
x1 |  | 504.70001220703125
y1 |  | 251.42135620117188
y0 |  | 239.33773803710938
x0 |  | 333.42999267578125

Path: | content.0.[11,11].bbox
Type: | addition

Key | Old | New
x1 |  | 515.7579956054688
y1 |  | 279.0213317871094
y0 |  | 266.9377136230469
x0 |  | 351.42999267578125

Path: | content.0.[12,12].bbox
Type: | addition

Key | Old | New
x1 |  | 513.8980102539062
y1 |  | 306.5377502441406
y0 |  | 294.5377502441406
x0 |  | 369.42999267578125

Path: | content.0.[13,13].bbox
Type: | addition

Key | Old | New
x1 |  | 464.739990234375
y1 |  | 334.1377258300781
y0 |  | 322.1377258300781
x0 |  | 369.42999267578125

Path: | content.0.[14,14].bbox
Type: | addition

Key | Old | New
x1 |  | 477.2619934082031
y1 |  | 361.82135009765625
y0 |  | 349.73773193359375
x0 |  | 351.42999267578125

Path: | content.0.[15,15].bbox
Type: | addition

Key | Old | New
x1 |  | 519.3820190429688
y1 |  | 389.3377380371094
y0 |  | 377.3377380371094
x0 |  | 369.42999267578125

Path: | content.0.[16,16].bbox
Type: | addition

Key | Old | New
x1 |  | 431.3500061035156
y1 |  | 416.9577331542969
y0 |  | 404.9577331542969
x0 |  | 369.42999267578125

Path: | content.0.[17,17].bbox
Type: | addition

Key | Old | New
x1 |  | 524.739990234375
y1 |  | 444.6413269042969
y0 |  | 432.5577087402344
x0 |  | 351.42999267578125

Path: | content.0.[18,18].bbox
Type: | addition

Key | Old | New
x1 |  | 508.8219909667969
y1 |  | 472.2413330078125
y0 |  | 460.15771484375
x0 |  | 369.42999267578125

Path: | content.0.[19,19].bbox
Type: | addition

Key | Old | New
x1 |  | 526.0180053710938
y1 |  | 499.7577209472656
y0 |  | 487.7577209472656
x0 |  | 387.42999267578125

Path: | content.0.[20,20].bbox
Type: | addition

Key | Old | New
x1 |  | 513.7000122070312
y1 |  | 527.357666015625
y0 |  | 515.357666015625
x0 |  | 387.42999267578125

Path: | content.0.[21,21].bbox
Type: | addition

Key | Old | New
x1 |  | 495.2619934082031
y1 |  | 555.0413208007812
y0 |  | 542.9577026367188
x0 |  | 369.42999267578125

Path: | content.0.[22,22].bbox
Type: | addition

Key | Old | New
x1 |  | 510.39398193359375
y1 |  | 582.5877075195312
y0 |  | 570.5877075195312
x0 |  | 387.42999267578125

Path: | content.0.[23,23].bbox
Type: | addition

Key | Old | New
x1 |  | 476.3800048828125
y1 |  | 610.1876831054688
y0 |  | 598.1876831054688
x0 |  | 387.42999267578125

Path: | content.0.[24,24].bbox
Type: | addition

Key | Old | New
x1 |  | 508.3420104980469
y1 |  | 693.0712890625
y0 |  | 625.7877197265625
x0 |  | 369.42999267578125

Path: | content.0.[25,25].bbox
Type: | addition

Key | Old | New
x1 |  | 505.35400390625
y1 |  | 720.5877075195312
y0 |  | 708.5877075195312
x0 |  | 387.42999267578125

1. Qui dignissimos quasi et nihil dolor aut consequuntur eaque qui neque placeat?

2. Aut cumque saepe est voluptatem asperiores sit enim accusamus!

3. Ut amet error et veritatis dolor.

1. Qui dignissimos quasi et nihil dolor aut consequuntur eaque qui neque placeat?

2. Aut cumque saepe est voluptatem asperiores sit enim accusamus!

3. Ut amet error et veritatis dolor.

4. In corporis sapiente qui commodi alias in autem delectus eum omnis reprehenderit!

5. Ea culpa vero cum iusto sequi.

6. Cum iusto aliquid aut quisquam nihil qui voluptas maiores.

1. In corporis sapiente qui commodi alias in autem delectus eum omnis reprehenderit!

2. Ea culpa vero cum iusto sequi.

3. Cum iusto aliquid aut quisquam nihil qui voluptas maiores.

1. Qui dignissimos quasi et nihil dolor aut

   consequuntur eaque qui neque placeat?

2. Aut cumque saepe est voluptatem

   asperiores sit enim accusamus!

3. Ut amet error et veritatis dolor.

a) Qui dignissimos quasi et nihil dolor

aut consequuntur eaque qui neque

placeat?

1. Aut cumque saepe est voluptatem

   asperiores sit enim accusamus!

2. Ut amet error et veritatis dolor.

3. In corporis sapiente qui commodi

alias in autem delectus eum omnis

reprehenderit!

e) Ea culpa vero cum iusto sequi.

i) Qui dignissimos quasi et nihil

dolor aut consequuntur eaque

qui neque placeat?

ii) Aut cumque saepe est

voluptatem asperiores sit enim

accusamus!

iii) Ut amet error et veritatis dolor.

(1) Qui dignissimos quasi et

nihil dolor aut consequuntur

eaque qui neque placeat?

(2) Aut cumque saepe est

voluptatem asperiores sit

enim accusamus!

1. Ut amet error et veritatis

   dolor.

2. In corporis sapiente qui

commodi alias in autem

1. Qui dignissimos quasi et nihil dolor aut consequuntur eaque qui neque placeat?

2. Aut cumque saepe est voluptatem asperiores sit enim accusamus!

3. Ut amet error et veritatis dolor.

1. Qui dignissimos quasi et nihil dolor aut consequuntur eaque qui neque placeat?

2. Aut cumque saepe est voluptatem asperiores sit enim accusamus!

3. Ut amet error et veritatis dolor.

4. In corporis sapiente qui commodi alias in autem delectus eum omnis reprehenderit!

5. Ea culpa vero cum iusto sequi.

6. Cum iusto aliquid aut quisquam nihil qui voluptas maiores.

1. In corporis sapiente qui commodi alias in autem delectus eum omnis reprehenderit!

2. Ea culpa vero cum iusto sequi.

3. Cum iusto aliquid aut quisquam nihil qui voluptas maiores.

1. Qui dignissimos quasi et nihil dolor aut

   consequuntur eaque qui neque placeat?

2. Aut cumque saepe est voluptatem

   asperiores sit enim accusamus!

3. Ut amet error et veritatis dolor.

a) Qui dignissimos quasi et nihil dolor

aut consequuntur eaque qui neque

placeat?

1. Aut cumque saepe est voluptatem

   asperiores sit enim accusamus!

2. Ut amet error et veritatis dolor.

3. In corporis sapiente qui commodi

alias in autem delectus eum omnis

reprehenderit!

e) Ea culpa vero cum iusto sequi.

i) Qui dignissimos quasi et nihil

dolor aut consequuntur eaque

qui neque placeat?

ii) Aut cumque saepe est

voluptatem asperiores sit enim

accusamus!

iii) Ut amet error et veritatis dolor.

(1) Qui dignissimos quasi et

nihil dolor aut consequuntur

eaque qui neque placeat?

(2) Aut cumque saepe est

voluptatem asperiores sit

enim accusamus!

1. Ut amet error et veritatis

   dolor.

2. In corporis sapiente qui

commodi alias in autem

Path: | content.1.[7,7].bbox
Type: | addition

Key | Old | New
x1 |  | 224.2519989013672
y1 |  | 334.1377258300781
y0 |  | 322.1377258300781
x0 |  | 126.0199966430664

Path: | content.1.[15,15].bbox
Type: | addition

Key | Old | New
x1 |  | 163.94000244140625
y1 |  | 582.5877075195312
y0 |  | 570.5877075195312
x0 |  | 90.02400207519531

Path: | content.1.[2,2].bbox
Type: | addition

Key | Old | New
x1 |  | 262.8800048828125
y1 |  | 196.19131469726562
y0 |  | 128.90774536132812
x0 |  | 126.0199966430664

Path: | content.1.[3,3].bbox
Type: | addition

Key | Old | New
x1 |  | 280.6639709472656
y1 |  | 223.70773315429688
y0 |  | 211.70773315429688
x0 |  | 144.02000427246094

Path: | content.1.[4,4].bbox
Type: | addition

Key | Old | New
x1 |  | 191.08999633789062
y1 |  | 251.33773803710938
y0 |  | 239.33773803710938
x0 |  | 144.02000427246094

Path: | content.1.[5,5].bbox
Type: | addition

Key | Old | New
x1 |  | 241.9039764404297
y1 |  | 279.0213317871094
y0 |  | 266.9377136230469
x0 |  | 108.0199966430664

Path: | content.1.[6,6].bbox
Type: | addition

Key | Old | New
x1 |  | 243.94398498535156
y1 |  | 306.5377502441406
y0 |  | 294.5377502441406
x0 |  | 126.0199966430664

Path: | content.1.[9,9].bbox
Type: | addition

Key | Old | New
x1 |  | 282.32000732421875
y1 |  | 417.0413513183594
y0 |  | 377.3377380371094
x0 |  | 108.0199966430664

Path: | content.1.[12,12].bbox
Type: | addition

Key | Old | New
x1 |  | 242.08999633789062
y1 |  | 499.7577209472656
y0 |  | 487.7577209472656
x0 |  | 108.0199966430664

Path: | content.1.[11,11].bbox
Type: | addition

Key | Old | New
x1 |  | 264.32000732421875
y1 |  | 472.2413330078125
y0 |  | 460.15771484375
x0 |  | 90.02400207519531

Path: | content.1.[13,13].bbox
Type: | addition

Key | Old | New
x1 |  | 279.33599853515625
y1 |  | 527.4412841796875
y0 |  | 515.357666015625
x0 |  | 72.02400207519531

Path: | content.1.[14,14].bbox
Type: | addition

Key | Old | New
x1 |  | 233.02398681640625
y1 |  | 554.9577026367188
y0 |  | 542.9577026367188
x0 |  | 90.02400207519531

Path: | content.1.[16,16].bbox
Type: | addition

Key | Old | New
x1 |  | 271.4040222167969
y1 |  | 637.871337890625
y0 |  | 598.1876831054688
x0 |  | 72.02400207519531

Path: | content.1.[17,17].bbox
Type: | addition

Key | Old | New
x1 |  | 199.00999450683594
y1 |  | 665.3876953125
y0 |  | 653.3876953125
x0 |  | 90.02400207519531

delectus eum omnis

reprehenderit!

1. Ea culpa vero cum iusto

   sequi.

2. Cum iusto aliquid aut

quisquam nihil qui voluptas

maiores.

iv) In corporis sapiente qui

commodi alias in autem

delectus eum omnis

reprehenderit!

1. Ea culpa vero cum iusto sequi.

2. Cum iusto aliquid aut quisquam

nihil qui voluptas maiores.

f) Cum iusto aliquid aut quisquam

nihil qui voluptas maiores.

4) In corporis sapiente qui commodi alias

in autem delectus eum omnis

reprehenderit!

1. Ea culpa vero cum iusto sequi.

2. Cum iusto aliquid aut quisquam nihil

qui voluptas maiores.

delectus eum omnis

reprehenderit!

1. Ea culpa vero cum iusto

   sequi.

2. Cum iusto aliquid aut

quisquam nihil qui voluptas

maiores.

iv) In corporis sapiente qui

commodi alias in autem

delectus eum omnis

reprehenderit!

1. Ea culpa vero cum iusto sequi.

2. Cum iusto aliquid aut quisquam

nihil qui voluptas maiores.

f) Cum iusto aliquid aut quisquam

nihil qui voluptas maiores.

4) In corporis sapiente qui commodi alias

in autem delectus eum omnis

reprehenderit!

1. Ea culpa vero cum iusto sequi.

2. Cum iusto aliquid aut quisquam nihil

qui voluptas maiores.

Parent File Contents